from .xvideos import XVideos
import json
def main():
    xvideos = XVideos()
    print(xvideos.download_low('https://www.xvideos.com/video.ubillud1141/salgo_de_compras_y_termino_cogiendo_con_la_cajera.', "porno/peru"))
    #print(xvideos.fresh())

if __name__ == "__main__":
    main()
